==> PyBBIO-0.9.2.tar.gz: PyBBIO-0.9.2/README.md <==
======
PyBBIO
======

http://github.com/alexanderhiam/PyBBIO

Copyright (c) 2012-2014 - Alexander Hiam <hiamalexander@gmail.com>

Released under the MIT license

PyBBIO is a Python library for Arduino-style hardware IO support on the 
BeagleBone and BeagleBone Black. It supports the GPIO, ADC, PWM, UART
and I2C modules, and also includes a number of additional libraries for 
added functionality.

Documentation can be found at http://github.com/alexanderhiam/PyBBIO/wiki

License
=======

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
    THE SOFTWARE.

==> PyBBIO-0.9.4.tar.gz: PyBBIO-0.9.4/README.md <==
PyBBIO
======

http://github.com/graycatlabs/PyBBIO

Copyright (c) 2012-2015 - Alexander Hiam <alex@graycat.io>

Released under the MIT license

PyBBIO is a Python library for Arduino-style hardware IO support on the 
BeagleBone and BeagleBone Black. It supports the GPIO, ADC, PWM, UART,
SPI, I2C and eQEP modules, and also includes a number of additional libraries
for added functionality.

Documentation can be found at http://github.com/graycatlabs/PyBBIO/wiki

License
=======

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
    THE SOFTWARE.
